/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { Ioc } from '@athenna/ioc';
import { Http, Router as HttpRoute } from '@athenna/http';
export declare class Application {
    /**
     * Simple logger for Application class.
     *
     * @private
     */
    private logger;
    /**
     * An instance of the Ioc class that is a Monostate with
     * the Awilix container inside.
     *
     * @private
     */
    private readonly container;
    /**
     * An instance of the application. Is here that the
     * client will bootstrap his type of application.
     *
     * @private
     */
    private readonly extension;
    private httpServer;
    private httpRoute;
    constructor(extension: string);
    /**
     * An instance of the Ioc class that is a Monostate with
     * the Awilix container inside.
     *
     * @return Ioc
     */
    getContainer(): Ioc;
    /**
     * An instance of the Http class or an exception if it's not
     * booted.
     *
     * @return Http
     */
    getHttpServer(): Http;
    /**
     * An instance of the Router class or an exception if it's not
     * booted.
     *
     * @return HttpRoute
     */
    getHttpRoute(): HttpRoute;
    /**
     * Boot a new HttpServer inside this Application instance.
     *
     * @return void
     */
    bootHttpServer(): Promise<Http>;
    /**
     * Shutdown the HttpServer inside this Application instance.
     *
     * @return void
     */
    shutdownHttpServer(): Promise<void>;
    /**
     * Preload the file according to filePath. This is usefully
     * to preload default files of each type of application. Such
     * as routes and Kernels
     *
     * @param filePath
     * @private
     */
    private preloadFile;
    /**
     * Resolve the Kernel of the http server
     *
     * @private
     */
    private resolveHttpKernel;
}
